# 更新日志
## kaa
### v2025.3.22.0
脚本：
* [新增] 支持处理培育中技能卡自选删除（#f026f5a）
* [新增] 支持 Windows 平台的启动游戏（#04ddac5）
* [新增] 支持跳过培育结束的演出（#cc73188）
* [新增] 配置文件中引入 windows 截图方式（#0f92c6f）
* [修复] 修复某些情况下无法检测到进行中培育（#9e764c7）
* [修复] 修复某些情况下会跳过未读交流时会发生误触（#46c7354）
* [修复] 修复某些情况下竞赛时会卡在 SKIP 按钮上（#69a5987）
* [修复] 修复进入竞赛时无法跳过赛季奖励（#8356fa1）
* [重构] 将 AutoHotKey.exe 移动到 ksaa-res 包内（#1c063f3）
* [重构] 将培育中 acquisitions 函数所有 OCR 改为模板匹配（#6e336d9）
* [重构] 重构 toolbar_home，提取 toolbar_menu（#425e998）

框架：
* [新增] 将 kotonebot.client.Device 类分为了 AndroidDevice 和 WindowsDevice（#abe9b0a）
* [新增] 引入对 Windows 的支持（#d38bb16）
* [新增] 新增图像预处理器（#b831e9e）
* [修复] 修复首次启动时创建的配置版本号不正确（#aab6fc3）

开发工具：
* [新增] ImageAnnotation 中支持修改现有定义的标注类型（#7bd921b）

其他：
* [其他] 移除无用 import（#f902315）
* [其他] 添加针对 DMM/PC 平台的 `启动（Windows）.bat` 文件（#a86004b）
* [其他] 增加 Windows 平台依赖（#45a9838）
* [其他] 修复 just package 命令未不会自动创建环境的问题（#d08af8f）

### v2025.3.15.2
脚本：
* [修复] 修复培育开始时部分偶像会卡在偶像选择页面的问题（#6429826b）

框架：
* [修复] 修复雷电模拟器的自启动失败问题 & 调整相关UI（#972a4789）

### v2025.3.15.1
脚本：
* [修复] 再次修复对于某些偶像，培育开始时会卡在偶像选择页（#80be65d）

### v2025.3.15.0
脚本：
* [修复] 修复没有配置文件时，升级配置会失败的问题（#7f00eef）
* [修复] 修复扭蛋在慢速设备下的两个问题（#8f7650e）
* [修复] 修复了社团奖励领取后，ocr过早检测的问题（#54787f4）
* [修复] 修复了某些情况下社团奖励领取失效（#76475f4）
* [修复] 修复进入竞赛时有时会发生误触（#facac04）
* [修复] 修复对于某些偶像，培育开始时会卡在偶像选择页（#f13244a）
* [新增] 新增扭蛋机功能，支持任意次数的任意类型扭蛋（#fe3dd29）
* [新增] 新增升级一张低等级支援卡的任务（#a0216ba）
* [新增] 领取社团奖励（笔记请求）和送礼物（#e0cf155）
* [新增] 在配置项中加入跟踪功能的启停（#9949f5b）
* [新增] 竞赛支持选择第几个挑战者(1/2/3)（#6dc4cee）
* [新增] 支持kuyo模拟器启动（#b7805a2）
* [新增] 新增推荐卡检测严格模式（#ea3f931）
* [新增] 新增跟踪功能 & 支持跟踪推荐卡检测（#9a45a9b）
* [重构] 用ocr来区分社团奖励中的笔记请求是否结束（#f0077e3）
* [重构] 将 PIdol 改为 IntEnum（#724ad9f）
* [重构] 用资源文件和HintPoint代替club_reward中硬编码的坐标（#818acb6）
* [重构] 把kuyo启动作为start_game的一个子选项 & 添加包名自定义配置（#179cdfe）
* [重构] 合并 start_game 和 start_kuyo_and_game（#dd225ef）

界面：
* [修复] 修复长多选 Dropdown 在选择一个选项后滚动会自动重置的问题（#3283f15）
* [新增] 改进错误报告上传功能（#252cccf）

框架：
* [新增] create_device 时判断连接结果（#05e471a）
* [新增] 调试图片移除信息改为 VERBOSE 等级（#4afed09）
* [新增] MockDevice 新增支持 mock 图片数据（#1409255）

其他：
* [文档] 修改 README 路线图（#c4affe9）
* [文档] 纠正 REAMDE 中 アノマリー 拼写错误（#7d16bd6）
* [文档] 更新 README（#a140149）
* [其他] 从 git tags 中自动提取版本号（#64ae6ee）
* [其他] 为配置备份文件设置 gitignore（#392c8ab）
* [其他] XcantloadX/kotones-auto-assistant into main（#759e8c3）
* [其他] 将expect_wait前面的if not删去（#0b3e55e）
* [其他] 新增了pnpm-lock，在pnpm包管理器下确保依赖一致（#63e0772）
* [其他] 移除了club_reward.py中一些无用的import（#7dca24a）

### v2025.3.9.4
脚本：
* [修复] 修复培育中卡在考试前的问题

### v2025.3.9.3
其他：
* 降级 numpy<2.0，修复“A module that was compiled using NumPy 1.x cannot be run in NumPy 2.0.0 as it may crash.”问题

### v2025.3.9.1、v2025.3.9.2
其他：
* 降级 onnxruntime==1.14.0，修复“ImportError: DLL load failed while importing onnxruntime_pybind11_state”问题

### v2025.3.9.0
脚本：
* [修复] 修复部分情况下工作分配偶像选择页面报错（#a35e6c3）
* [修复] 修复培育中强化技能卡时有几率卡在确认按钮上（#221721a）
* [新增] 支持指定培育中行动优先级（#fc8c456）
* [新增] 支持处理培育结束时的未读交流（#452ba67）
* [新增] 培育中支持优先选择 SP 课程（#ee3808c）
* [新增] 培育中文化课（授業）行动支持处理自习事件（#47287fd）

界面：
* [新增] UI 上实时展示设备画面（#72a1a17）

框架：
* [修复] 修复调试模式下内存中截图数据不会释放的问题（#bead31a）
* [修复] 修复启动模拟器前不会自动检测是否已启动的问题（#71d75b7）
* [修复] 修复若软件处于中文目录，读取图片资源失败的问题（#a8aee32）
* [新增] 降低双击默认速度（#e63ad2d）
* [新增] 支持启动 kaa 前自动启动模拟器（#8ee51ba）
* [重构] 移动 grayscaled 和 unify_image 函数的位置（#500e11d）
* [重构] 移动 util 模块位置（#0d3e5de）
* [重构] 移除原有 kotonebot.run 模块中函数，改用 Kotonebot 类（#508d81c）

开发工具：
* [修复] 修复写出 dumps 文件时的编码问题（#d5c64df）
* [新增] 优化 DumpViewer 调用堆栈部分与时间部分的显示（#41d4c4c）
* [新增] ImageAnnotation 新增 description 字段（#425057d）
* [新增] DumpViewer 新增滚动锁定按钮（#79927a7）
* [新增] DumpViewer 两次结果之间新增时间差显示（#e3583f2）
* [重构] 将调试 WS 消息体提取为 pydantic Model（#abf7fbc）

其他：
* [其他] R.py 中的 HintBox 类型的注释也加入裁剪后图片的展示（#7907e44）

### v2025.3.1.0
脚本：
* [新增] 新增支持指定回忆编成编号（#6482962）
* [新增] 优化培育与日常流程，修复一些 bug（#145f97f）
* [新增] 支持处理外出行动 & 优化部分流程（#03fdfaa）
* [新增] 新增支持处理技能卡强化选择事件（#133f084）
* [新增] 培育中支持识别睡意 T 卡（眠気）（#5a68500）
* [修复] 修复课程中无法处理当前回合无剩余手牌的情况（#bfb574c）
* [修复] 修复课程中遇到四/五张手牌时会卡住的问题（#ae22253）
* [修复] 修复某些情况下会卡在培育开始第二步（#73dc4d8）
* [修复] 修复某些情况下会卡在工作分配偶像选择页面（#2ff655f）

界面：
* [新增] UI 上新增更新日志 Tab（#07be7b3）
* [新增] 新增一键上传日志报告功能（#62d5805）

框架：
* [新增] device.click() 方法新增支持传入 tuple[int, int]（#f146038）
* [新增] adb_raw 截图方法加入超时自动重试（#08f382c）
* [新增] 为 device.click() 方法添加可视调试信息（#be37164）
* [新增] 为 adb_raw 截图方式的截图线程加入自动重试（#9b25098）
* [修复] 修复了 device.click() 调试信息在没有截图数据时会报错（#f0a3baa）
* [修复] 修复写入调试数据前不会自动清空上次数据的问题（#80e04ee）

其他：
* [新增] ImageAnntation 页面与 Python 代码引入 HintPoint 支持（#949e28d）
* [修复] 修复某些情况下会卡在领取任务奖励处（#f80660e）
* [单测] 移除无用单元测试（#54f9b03）

### v2025.2.23.0
修复：
* 返回首页时无法处理弹出某些弹窗
* 培育中，某些情况下会卡在饮料领取弹窗
* 培育中，某些情况下会在饮料领取时报错

新增：
* 支持处理游戏本体更新弹窗
* 培育中，支持处理技能卡移除事件
* 培育结束时，支持处理“偶像强化月”活动的新纪录弹窗
* UI 标题上新增版本号显示

### v2025.2.20.1
修复：
* ADB 设备连接失败的问题

### v2025.2.20.0
初始版本。